@@ -29,6 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QDirIterator>
+#include <QPair>
 #include <QDate>
 
 #ifdef Q_OS_ANDROID
@@ -58,36 +59,53 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #define PIX_URI "org.maui.pix"
 
-static const QList<QUrl> getFolderImages(const QString &path)
+//static const QList<QUrl> getFolderImages(const QString &path)
+//{
+//    QList<QUrl> urls;
+
+//    if (QFileInfo(path).isDir()) {
+//        QDirIterator it(path, FMStatic::FILTER_LIST[FMStatic::FILTER_TYPE::IMAGE], QDir::Files, QDirIterator::NoIteratorFlags);
+//        while (it.hasNext())
+//            urls << QUrl::fromLocalFile(it.next());
+
+//    } else if (QFileInfo(path).isFile())
+//        urls << path;
+
+//    return urls;
+//}
+
+static const QPair<QString, QList<QUrl>> openFiles(const QStringList &files)
 {
     QList<QUrl> urls;
+    QString module;
 
-    if (QFileInfo(path).isDir()) {
-        QDirIterator it(path, FMStatic::FILTER_LIST[FMStatic::FILTER_TYPE::IMAGE], QDir::Files, QDirIterator::NoIteratorFlags);
-        while (it.hasNext())
-            urls << QUrl::fromLocalFile(it.next());
-
-    } else if (QFileInfo(path).isFile())
-        urls << path;
-
-    return urls;
-}
-
-static const QList<QUrl> openFiles(const QStringList &files)
-{
-    QList<QUrl> urls;
-
-    if (files.size() > 1) {
+    if (files.size() > 1)
+    {
+        module = "viewer";
         for (const auto &file : files)
+        {
+            if(FMStatic::isDir(QUrl::fromUserInput(file)))
+                continue;
+
             urls << QUrl::fromUserInput(file);
-    } else if (files.size() == 1) {
-        auto folder = QFileInfo(files.first()).dir().absolutePath();
-        urls = getFolderImages(folder);
-        urls.removeOne(QUrl::fromLocalFile(files.first()));
-        urls.insert(0, QUrl::fromLocalFile(files.first()));
+        }
+    } else if (files.size() == 1)
+    {
+        if(FMStatic::isDir(QUrl::fromUserInput(files.first())))
+        {
+            module = "folder";
+            urls << QUrl::fromUserInput(files.first());
+        }else
+        {
+            module = "viewer";
+            //            auto folder = QFileInfo(files.first()).dir().absolutePath();
+            //            urls = getFolderImages(folder);
+            //            urls.removeOne(QUrl::fromLocalFile(files.first()));
+            urls.insert(0, QUrl::fromLocalFile(files.first()));
+        }
     }
 
-    return urls;
+    return {module, urls};
 }
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
@@ -125,18 +143,44 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.process(app);
 
     about.processCommandLine(&parser);
-
     const QStringList args = parser.positionalArguments();
 
-    QList<QUrl> pics;
+    QPair<QString, QList<QUrl>> arguments;
+    arguments.first = "gallery";
+
     if (!args.isEmpty())
-        pics = openFiles(args);
+    {
+        arguments = openFiles(args);
+    }
 
     QQmlApplicationEngine engine;
-    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated, [&]() {
-        if (!pics.isEmpty())
-            Pix::instance()->openPics(pics);
-    });
+    QUrl url(QStringLiteral("qrc:/main.qml"));
+    QObject::connect(
+                &engine,
+                &QQmlApplicationEngine::objectCreated,
+                &app,
+                [url, arguments](QObject *obj, const QUrl &objUrl) {
+        if (!obj && url == objUrl)
+            QCoreApplication::exit(-1);
+
+        auto module = arguments.first;
+        auto data = arguments.second;
+
+        if (!data.isEmpty() )
+        {
+            if(module == "viewer")
+            {
+                Pix::instance()->openPics(data);
+            }else if(module == " folder")
+            {
+
+            }
+        }
+    },
+    Qt::QueuedConnection);
+
+    engine.rootContext()->setContextProperty("initModule", arguments.first);
+    engine.rootContext()->setContextProperty("initData", QUrl::toStringList(arguments.second));
 
     qmlRegisterSingletonInstance<Pix>(PIX_URI, 1, 0, "Collection", Pix::instance());
 
@@ -145,13 +189,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<CitiesModel>(PIX_URI, 1, 0, "CitiesList");
     qmlRegisterType<TagsModel>(PIX_URI, 1, 0, "TagsList");
 
-    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
-    if (engine.rootObjects().isEmpty())
-        return -1;
+    engine.load(url);
 
 #ifdef Q_OS_MACOS
-//    MAUIMacOS::removeTitlebarFromWindow();
-//    MauiApp::instance()->setEnableCSD(true); //for now index can not handle cloud accounts
+    //    MAUIMacOS::removeTitlebarFromWindow();
+    //    MauiApp::instance()->setEnableCSD(true); //for now index can not handle cloud accounts
 #endif
 
     return app.exec();
